==> open-xchange-usm_7.2.1.orig.tar.bz2: open-xchange-usm-7.2.1/com.openexchange.usm.ox_json.impl/src/com/openexchange/usm/ox_json/impl/AbstractJSONResult.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.ox_json.impl;

import static com.openexchange.usm.ox_json.JSONResultType.*;

import org.json.JSONArray;
import org.json.JSONObject;

import com.openexchange.usm.api.exceptions.USMIllegalStateException;
import com.openexchange.usm.ox_json.JSONResult;
import com.openexchange.usm.ox_json.JSONResultType;

public abstract class AbstractJSONResult implements JSONResult {

	public JSONArray getJSONArray() {
		throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_0, getErrorMessage(JSONArray));
	}

	public JSONObject getJSONObject() {
		throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_1, getErrorMessage(JSONObject));
	}

	public String getString() {
		throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_2, getErrorMessage(String));
	}

	private String getErrorMessage(JSONResultType expected) {
		return "Result from OX server is a " + getResultType() + ", expected " + expected;
	}

	@Override
	public String toString() {
		return "OX Result: " + toJSONString();
	}
}

==> open-xchange-usm_7.4.2.orig.tar.bz2: open-xchange-usm-7.4.2/com.openexchange.usm.ox_json.impl/src/com/openexchange/usm/ox_json/impl/AbstractJSONResult.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.ox_json.impl;

import static com.openexchange.usm.ox_json.JSONResultType.JSONArray;
import static com.openexchange.usm.ox_json.JSONResultType.JSONObject;
import static com.openexchange.usm.ox_json.JSONResultType.String;
import org.json.JSONArray;
import org.json.JSONObject;
import com.openexchange.usm.api.exceptions.USMIllegalStateException;
import com.openexchange.usm.ox_json.JSONResult;
import com.openexchange.usm.ox_json.JSONResultType;

public abstract class AbstractJSONResult implements JSONResult {

	public JSONArray getJSONArray() {
		throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_0, getErrorMessage(JSONArray));
	}

	public JSONObject getJSONObject() {
		throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_1, getErrorMessage(JSONObject));
	}

	public String getString() {
		throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_2, getErrorMessage(String));
	}

	private String getErrorMessage(JSONResultType expected) {
		return "Result from OX server is a " + getResultType() + ", expected " + expected;
	}

	@Override
	public String toString() {
		return "OX Result: " + toJSONString();
	}
}
